Coverage for /media/ldata/code/tendril/tendril/scripts/makelabels.py: 0%

# Coverage for /media/ldata/code/tendril/tendril/scripts/makelabels.py : 0%

## 14 statements 0 run 14 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 | """ This file is part of tendril See the COPYING, README, and INSTALL files for more information """ from tendril.entityhub import products from tendril.entityhub.db import controller from tendril.entityhub import serialnos from tendril.utils.config import INSTANCE_ROOT from tendril.dox.labelmaker import manager if __name__ == '__main__': snos = [x.sno for x in controller.get_serialnos_by_efield(efield="CBL-STRAIN-HBC-A-120E") ] snos += [x.sno for x in controller.get_serialnos_by_efield(efield="CBL-STRAIN-QBC-120E") ] snos += [x.sno for x in controller.get_serialnos_by_efield(efield="CBL-PIEZO") ] for sno in snos: product = products.get_product_by_core(serialnos.get_serialno_efield(sno=sno)) # noqa if product is not None: products.generate_labels(product, sno) manager.generate_pdfs(INSTANCE_ROOT, force=True)